@@ -4,4 +4,5 @@ __version__ = importlib.metadata.version("aiowire")
 
 from .event_loop import EventLoop
 from .poller import Poller
-from .wire import Wire, Sequence, ApplyM, Call, Repeat, Forever
+from .wire import Wire, Sequence, Call, Repeat, Forever
+from .wire import ApplyM, RepeatM, ForeverM
